@@ -438,10 +438,10 @@ def _compile(pattern, flags=0, kwargs=None):
 
     # Check the global flags for conflicts.
     version = (info.flags & ALL_VERSIONS) or DEFAULT_VERSION
-    if count_ones(version) > 1:
+    if version not in (0, VERSION0, VERSION1):
         raise ValueError("VERSION0 and VERSION1 flags are mutually incompatible")
 
-    if count_ones(info.flags & ALL_ENCODINGS) > 1:
+    if (info.flags & ALL_ENCODINGS) not in (0, ASCII, LOCALE, UNICODE):
         raise ValueError("ASCII, LOCALE and UNICODE flags are mutually incompatible")
 
     if not (info.flags & ALL_ENCODINGS):
@@ -460,6 +460,9 @@ def _compile(pattern, flags=0, kwargs=None):
     parsed = parsed.optimise(info)
     parsed = parsed.pack_characters(info)
 
+    # Get the required string.
+    req_offset, req_chars, req_flags = get_required_string(parsed, info.flags)
+
     # Build the named lists.
     named_lists = {}
     named_list_indexes = [None] * len(info.named_lists_used)
@@ -479,7 +482,7 @@ def _compile(pattern, flags=0, kwargs=None):
     if flags & DEBUG:
         parsed.dump(indent=0, reverse=reverse)
 
-    # Check of the features of the groups.
+    # Check the features of the groups.
     check_group_features(info, parsed)
 
     # Compile the parsed pattern. The result is a list of tuples.
@@ -519,7 +522,8 @@ def _compile(pattern, flags=0, kwargs=None):
     # by the PatternObject itself. Conversely, global flags like LOCALE _don't_
     # affect the code generation but _are_ needed by the PatternObject.
     compiled_pattern = _regex.compile(pattern, info.flags | version, code,
-      info.group_index, index_group, named_lists, named_list_indexes)
+      info.group_index, index_group, named_lists, named_list_indexes,
+      req_offset, req_chars, req_flags)
 
     # Do we need to reduce the size of the cache?
     if len(_cache) >= _MAXCACHE:
